@@ -475,54 +475,141 @@ cfg_lexer_include_file_simple(CfgLexer *self, const gchar *filename)
   return FALSE;
 }
 
+static int
+_cfg_lexer_glob_err (const char *p, gint e)
+{
+  if (e != ENOENT)
+    {
+      msg_debug ("Error processing path for inclusion",
+                 evt_tag_str("path", p),
+                 evt_tag_errno("errno", e),
+                 NULL);
+      return -1;
+    }
+  return 0;
+}
+
+#ifndef GLOB_NOMAGIC
+#define GLOB_NOMAGIC 0
+
+int
+__glob_pattern_p (const char *pattern)
+{
+  register const char *p;
+  int open = 0;
+
+  for (p = pattern; *p != '\0'; ++p)
+    switch (*p)
+      {
+      case '?':
+      case '*':
+        return 1;
+
+      case '\\':
+        if (p[1] != '\0')
+          ++p;
+        break;
+
+      case '[':
+        open = 1;
+        break;
+
+      case ']':
+        if (open)
+          return 1;
+        break;
+      }
+
+  return 0;
+}
+#else
+#define HAVE_GLOB_NOMAGIC 1
+#endif
+
+static gboolean
+cfg_lexer_include_file_add(CfgLexer *self, const gchar *fn)
+{
+  CfgIncludeLevel *level;
+
+  level = &self->include_stack[self->include_depth];
+  level->include_type = CFGI_FILE;
+
+  level->file.files = g_slist_insert_sorted(level->file.files,
+                                            strdup(fn),
+                                            (GCompareFunc) strcmp);
+
+  msg_debug("Adding include file",
+            evt_tag_str("filename", fn),
+            NULL);
+
+  return TRUE;
+}
+
 static gboolean
 cfg_lexer_include_file_glob_at(CfgLexer *self, const gchar *pattern)
 {
   glob_t globbuf;
   size_t i;
-  gboolean status = FALSE;
   int r;
 
-  r = glob(pattern, 0, NULL, &globbuf);
+  r = glob(pattern, GLOB_NOMAGIC, _cfg_lexer_glob_err, &globbuf);
 
-  if (r == GLOB_NOMATCH)
-    return TRUE;
   if (r != 0)
-    return FALSE;
+    {
+      globfree(&globbuf);
+      if (r == GLOB_NOMATCH)
+        {
+#ifndef HAVE_GLOB_NOMAGIC
+          if (!__glob_pattern_p (pattern))
+            {
+              self->include_depth++;
+              return cfg_lexer_include_file_add(self, pattern);
+            }
+#endif
+          return FALSE;
+        }
+      return TRUE;
+    }
 
+  self->include_depth++;
   for (i = 0; i < globbuf.gl_pathc; i++)
-    status |= cfg_lexer_include_file(self, globbuf.gl_pathv[i]);
+    {
+      cfg_lexer_include_file_add(self, globbuf.gl_pathv[i]);
+    }
 
   globfree(&globbuf);
 
-  return status;
+  return TRUE;
 }
 
 static gboolean
 cfg_lexer_include_file_glob(CfgLexer *self, const gchar *filename_)
 {
   const gchar *path = cfg_args_get(self->globals, "include-path");
+  gboolean process = FALSE;
 
   if (filename_[0] == '/' || !path)
-    return cfg_lexer_include_file_glob_at(self, filename_);
+    process = cfg_lexer_include_file_glob_at(self, filename_);
   else
     {
       gchar **dirs;
       gchar *cf;
       gint i = 0;
-      gboolean status = FALSE;
 
       dirs = g_strsplit(path, G_SEARCHPATH_SEPARATOR_S, 0);
       while (dirs && dirs[i])
         {
           cf = g_build_filename(dirs[i], filename_, NULL);
-          status |= cfg_lexer_include_file_glob_at(self, cf);
+          process |= cfg_lexer_include_file_glob_at(self, cf);
           g_free(cf);
           i++;
         }
       g_strfreev(dirs);
-      return status;
     }
+  if (process)
+    return cfg_lexer_start_next_include(self);
+  else
+    return TRUE;
 }
 
 gboolean
