@@ -242,7 +242,7 @@ log_reader_io_follow_file(gpointer s)
                 evt_tag_int("size", st.st_size),
                 NULL);
 
-      if (pos < st.st_size)
+      if (pos < st.st_size || !S_ISREG(st.st_mode))
         {
           /* we have data to read */
           log_reader_io_process_input(s);
@@ -337,28 +337,27 @@ log_reader_start_watches(LogReader *self)
       /* NOTE: the fd may not be set here, as it may not have been opened yet */
       iv_timer_register(&self->follow_timer);
     }
-  else if (fd < 0)
-    {
-      msg_error("In order to poll non-yet-existing files, follow_freq() must be set",
-                NULL);
-      return FALSE;
-    }
   else
     {
+      if (fd < 0)
+        {
+          msg_error("In order to poll non-yet-existing files, follow_freq() must be set",
+                    NULL);
+          return FALSE;
+        }
+
       /* we have an FD, it is possible to poll it, register it  */
       self->fd_watch.fd = fd;
       if (self->pollable_state < 0)
         {
-          if (iv_fd_register_try(&self->fd_watch) == 0)
-            self->pollable_state = 1;
-          else
-            self->pollable_state = 0;
+          self->pollable_state = !iv_fd_register_try(&self->fd_watch);
         }
       else if (self->pollable_state > 0)
         {
           iv_fd_register(&self->fd_watch);
         }
-      else
+
+      if (self->pollable_state == 0)
         {
           msg_error("Unable to determine how to monitor this fd, follow_freq() not set and it is not possible to poll it with the current ivykis polling method, try changing IV_EXCLUDE_POLL_METHOD environment variable",
                     evt_tag_int("fd", fd),
