@@ -572,7 +572,7 @@ pdbtool_match(int argc, char *argv[])
                     name = nv_registry_get_handle_name(logmsg_registry, dbg_info->pnode->handle, &name_len);
 
                   printf("PDBTOOL_DEBUG=%d:%d:%d:%d:%d:%s:%s\n",
-                        i++, dbg_info->i, dbg_info->node->keylen, dbg_info->match_off, dbg_info->match_len,
+                        i, dbg_info->i, dbg_info->node->keylen, dbg_info->match_off, dbg_info->match_len,
                         dbg_info->pnode ? r_parser_type_name(dbg_info->pnode->type) : "",
                         dbg_info->pnode && name_len ? name : ""
                         );
@@ -847,6 +847,10 @@ pdbtool_dump(int argc, char *argv[])
             pdbtool_walk_tree(root, 0, FALSE);
         }
     }
+  else
+    {
+      fprintf(stderr, "Neither --program-tree nor --program was specified, doing nothing\n");
+    }
 
   pattern_db_free(patterndb);
 
@@ -855,6 +859,8 @@ pdbtool_dump(int argc, char *argv[])
 
 static GOptionEntry dump_options[] =
 {
+  { "pdb",       'p', 0, G_OPTION_ARG_STRING, &patterndb_file,
+    "Name of the patterndb file", "<patterndb_file>" },
   { "program", 'P', 0, G_OPTION_ARG_STRING, &match_program,
     "Program name ($PROGRAM) to dump", "<program>" },
   { "program-tree", 'T', 0, G_OPTION_ARG_NONE, &dump_program_tree,
