@@ -210,15 +210,16 @@ main(int argc, char *argv[])
       return 1;
     }
 
-  msg_init(FALSE);
-
   if (display_version)
     {
+      msg_init(TRUE);
+
       version();
       return 0;
     }
   if (display_module_registry)
     {
+      msg_init(TRUE);
       plugin_list_modules(stdout, TRUE);
       return 0;
     }
